@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ai-code" "1.21"
-  "Unified interface for AI coding CLI such as Codex, Copilot CLI, Opencode, Grok CLI, etc."
+(define-package "ai-code" "1.22"
+  "Unified interface for AI coding CLI such as Claude Code, Codex CLI, Gemini CLI, Copilot CLI, Opencode, Grok CLI, etc."
   '((emacs     "28.1")
     (transient "0.8.0")
     (magit     "2.1.0"))
   :url "https://github.com/tninja/ai-code-interface.el"
-  :commit "7e60511603dd0e5db931f769de1bdb0966d417ad"
-  :revdesc "7e60511603dd"
+  :commit "3cd3bf60a9ad7a25bb53a86f8222709820f6f7c4"
+  :revdesc "3cd3bf60a9ad"
   :authors '(("Kang Tu" . "tninja@gmail.com"))
   :maintainers '(("Kang Tu" . "tninja@gmail.com")))
